==> huaweicloudsdkivs-3.0.64-py2.py3-none-any.whl: huaweicloudsdkivs/v2/model/detect_standard_by_id_card_image_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DetectStandardByIdCardImageResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'meta': 'Meta',
        'result': 'IvsStandardByIdCardImageResponseBodyResult'
    }

    attribute_map = {
        'meta': 'meta',
        'result': 'result'
    }

    def __init__(self, meta=None, result=None):
        """DetectStandardByIdCardImageResponse - a model defined in huaweicloud sdk"""
        
        super(DetectStandardByIdCardImageResponse, self).__init__()

        self._meta = None
        self._result = None
        self.discriminator = None

        if meta is not None:
            self.meta = meta
        if result is not None:
            self.result = result

    @property
    def meta(self):
        """Gets the meta of this DetectStandardByIdCardImageResponse.


        :return: The meta of this DetectStandardByIdCardImageResponse.
        :rtype: Meta
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this DetectStandardByIdCardImageResponse.


        :param meta: The meta of this DetectStandardByIdCardImageResponse.
        :type: Meta
        """
        self._meta = meta

    @property
    def result(self):
        """Gets the result of this DetectStandardByIdCardImageResponse.


        :return: The result of this DetectStandardByIdCardImageResponse.
        :rtype: IvsStandardByIdCardImageResponseBodyResult
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this DetectStandardByIdCardImageResponse.


        :param result: The result of this DetectStandardByIdCardImageResponse.
        :type: IvsStandardByIdCardImageResponseBodyResult
        """
        self._result = result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetectStandardByIdCardImageResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkivs-3.0.92-py2.py3-none-any.whl: huaweicloudsdkivs/v2/model/detect_standard_by_id_card_image_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DetectStandardByIdCardImageResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'meta': 'Meta',
        'result': 'IvsStandardByIdCardImageResponseBodyResult'
    }

    attribute_map = {
        'meta': 'meta',
        'result': 'result'
    }

    def __init__(self, meta=None, result=None):
        """DetectStandardByIdCardImageResponse

        The model defined in huaweicloud sdk

        :param meta: 
        :type meta: :class:`huaweicloudsdkivs.v2.Meta`
        :param result: 
        :type result: :class:`huaweicloudsdkivs.v2.IvsStandardByIdCardImageResponseBodyResult`
        """
        
        super(DetectStandardByIdCardImageResponse, self).__init__()

        self._meta = None
        self._result = None
        self.discriminator = None

        if meta is not None:
            self.meta = meta
        if result is not None:
            self.result = result

    @property
    def meta(self):
        """Gets the meta of this DetectStandardByIdCardImageResponse.


        :return: The meta of this DetectStandardByIdCardImageResponse.
        :rtype: :class:`huaweicloudsdkivs.v2.Meta`
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this DetectStandardByIdCardImageResponse.


        :param meta: The meta of this DetectStandardByIdCardImageResponse.
        :type meta: :class:`huaweicloudsdkivs.v2.Meta`
        """
        self._meta = meta

    @property
    def result(self):
        """Gets the result of this DetectStandardByIdCardImageResponse.


        :return: The result of this DetectStandardByIdCardImageResponse.
        :rtype: :class:`huaweicloudsdkivs.v2.IvsStandardByIdCardImageResponseBodyResult`
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this DetectStandardByIdCardImageResponse.


        :param result: The result of this DetectStandardByIdCardImageResponse.
        :type result: :class:`huaweicloudsdkivs.v2.IvsStandardByIdCardImageResponseBodyResult`
        """
        self._result = result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetectStandardByIdCardImageResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
